@@ -59,7 +59,7 @@ KigWidget::KigWidget( KigPart* part,
   part->addWidget(this);
 
   setFocusPolicy(Qt::ClickFocus);
-  setAttribute( Qt::WA_NoBackground, true );
+  setAttribute( Qt::WA_OpaquePaintEvent, true );
   setMouseTracking(true);
 
   curPix = QPixmap( size() );
@@ -309,7 +309,7 @@ KigView::KigView( KigPart* part,
   connect( part, &KigPart::recenterScreen, this, &KigView::slotInternalRecenterScreen );
 
   mlayout = new QGridLayout( this );
-  mlayout->setMargin( 2 );
+  mlayout->setContentsMargins( 2 ,  2 ,  2 ,  2 );
   mlayout->setSpacing( 2 );
   mrightscroll = new QScrollBar( Qt::Vertical, this );
   mrightscroll->setObjectName( QStringLiteral("Right Scrollbar") );
@@ -467,7 +467,7 @@ QSize KigWidget::sizeHint() const
 
 void KigWidget::wheelEvent( QWheelEvent* e )
 {
-  int delta = e->delta();
+  int delta = e->angleDelta().y();
   Qt::Orientation orient = e->orientation();
   if ( orient == Qt::Vertical )
     mview->scrollVertical( delta );
